==> haskell-cipher-aes128-0.7.0.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
key: cipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: 8bc9e2075a608388dd287a963e79bfa4
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-AjBklnlJqxQ3rMxO2aZy1C
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=77fff9de6de15e8cfa3572530a17c761
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-Blk4WpbEskpLLxAM7p400y
key: cipher-aes128-0.7.0.3-Blk4WpbEskpLLxAM7p400y
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: e5a52ec18a073e2e84da7a0243b15983
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-Blk4WpbEskpLLxAM7p400y
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    crypto-api-0.13.3-43rwgg6didD9Ww3YkDbwy5
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
